@@ -122,7 +122,7 @@ class Builder:
         target_build_dir.mkdir(parents=True, exist_ok=True)
         for item in [
             self._paths.shared_img_dir,
-            self._paths.shared_tikz_dir,
+            self._paths.shared_tikz_pdf_dir,
             self._paths.shared_code_dir,
         ]:
             self._setup_link(target_build_dir / item.name, item)
