@@ -1,9 +1,9 @@
 from logging import getLogger
 from pathlib import Path
-from random import randint
-from typing import List
+from random import choice
+from typing import Dict
 
-from pydantic import BaseModel
+from pydantic import BaseModel, EmailStr
 from sendgrid import SendGridAPIClient
 from sendgrid.helpers.mail import Mail
 from yaml import safe_load
@@ -14,22 +14,20 @@ from deckz.paths import GlobalPaths
 
 @app.command()
 def random(
-    inclusive_end: int,
-    inclusive_start: int = 1,
+    reason: str,
     current_dir: Path = Path("."),
 ) -> None:
     """Roll the dice and email the result."""
     logger = getLogger(__name__)
     config = MailsConfig.from_global_paths(GlobalPaths.from_defaults(current_dir))
-    result = randint(inclusive_start, inclusive_end)
-    logger.info(
-        f"I've drawn {result} randomly from {inclusive_start} to {inclusive_end}"
-    )
+    names = list(config.to)
+    name = choice(names)
+    logger.info(f"I've drawn {name} randomly from {', '.join(names)}")
     sendgrid_email = Mail(
         from_email=config.mail,
-        to_emails=config.to,
-        subject=f"deckz random from {inclusive_start} to {inclusive_end}: {result}",
-        plain_text_content="Hope you got lucky :)",
+        to_emails=list(config.to.values()),
+        subject=f"[deckz random] {reason}: {name} got picked",
+        plain_text_content="See subject :)",
     )
     client = SendGridAPIClient(config.api_key)
     client.send(sendgrid_email)
@@ -39,7 +37,7 @@ class MailsConfig(BaseModel):
 
     api_key: str
     mail: str
-    to: List[str]
+    to: Dict[str, EmailStr]
 
     @classmethod
     def from_global_paths(cls, paths: GlobalPaths) -> "MailsConfig":
